@@ -7,6 +7,7 @@ const GWeather = imports.gi.GWeather;
 const Lang = imports.lang;
 const Signals = imports.signals;
 
+const PermissionStore = imports.misc.permissionStore;
 const Util = imports.misc.util;
 
 // Minimum time between updates to show loading indication
@@ -17,9 +18,10 @@ const WeatherClient = new Lang.Class({
 
     _init: function() {
         this._loading = false;
+        this._locationValid = false;
         this._lastUpdate = GLib.DateTime.new_from_unix_local(0);
 
-        this._useAutoLocation = false;
+        this._autoLocationRequested = false;
         this._mostRecentLocation = null;
 
         this._gclueService = null;
@@ -27,6 +29,29 @@ const WeatherClient = new Lang.Class({
         this._gclueStarting = false;
         this._gclueLocationChangedId = 0;
 
+        this._weatherAuthorized = false;
+        this._permStore = new PermissionStore.PermissionStore((proxy, error) => {
+            if (error) {
+                log('Failed to connect to permissionStore: ' + error.message);
+                return;
+            }
+
+            this._permStore.LookupRemote('gnome', 'geolocation', (res, error) => {
+                if (error)
+                    log('Error looking up permission: ' + error.message);
+
+                let [perms, data] = error ? [{}, null] : res;
+                let  params = ['gnome', 'geolocation', false, data, perms];
+                this._onPermStoreChanged(this._permStore, '', params);
+            });
+        });
+        this._permStore.connectSignal('Changed',
+                                      Lang.bind(this, this._onPermStoreChanged));
+
+        this._locationSettings = new Gio.Settings({ schema_id: 'org.gnome.system.location' });
+        this._locationSettings.connect('changed::enabled',
+                                       Lang.bind(this, this._updateAutoLocation));
+
         this._world = GWeather.Location.get_world();
 
         let providers = GWeather.Provider.METAR |
@@ -55,6 +80,10 @@ const WeatherClient = new Lang.Class({
         return this._loading;
     },
 
+    get hasLocation() {
+        return this._locationValid;
+    },
+
     get info() {
         return this._weatherInfo;
     },
@@ -64,6 +93,9 @@ const WeatherClient = new Lang.Class({
     },
 
     update: function() {
+        if (!this._locationValid)
+            return;
+
         let now = GLib.DateTime.new_now_local();
         // Update without loading indication if the current info is recent enough
         if (this._weatherInfo.is_valid() &&
@@ -73,6 +105,12 @@ const WeatherClient = new Lang.Class({
             this._loadInfo();
     },
 
+    get _useAutoLocation() {
+        return this._autoLocationRequested &&
+               this._locationSettings.get_boolean('enabled') &&
+               this._weatherAuthorized;
+    },
+
     _loadInfo: function() {
         let id = this._weatherInfo.connect('updated', () => {
             this._weatherInfo.disconnect(id);
@@ -101,6 +139,7 @@ const WeatherClient = new Lang.Class({
 
         this._weatherInfo.abort();
         this._weatherInfo.set_location(location);
+        this._locationValid = (location != null);
 
         if (location)
             this._loadInfo();
@@ -156,11 +195,15 @@ const WeatherClient = new Lang.Class({
 
     _onAutomaticLocationChanged: function(settings, key) {
         let useAutoLocation = settings.get_boolean(key);
-        if (this._useAutoLocation == useAutoLocation)
+        if (this._autoLocationRequested == useAutoLocation)
             return;
 
-        this._useAutoLocation = useAutoLocation;
+        this._autoLocationRequested = useAutoLocation;
 
+        this._updateAutoLocation();
+    },
+
+    _updateAutoLocation: function() {
         this._updateLocationMonitoring();
 
         if (this._useAutoLocation)
@@ -183,6 +226,19 @@ const WeatherClient = new Lang.Class({
 
         if (!this._useAutoLocation || !this._gclueStarted)
             this._setLocation(this._mostRecentLocation);
+    },
+
+    _onPermStoreChanged: function(proxy, sender, params) {
+        let [table, id, deleted, data, perms] = params;
+
+        if (table != 'gnome' || id != 'geolocation')
+            return;
+
+        let permission = perms['org.gnome.Weather.Application'] || ['NONE'];
+        let [accuracy] = permission;
+        this._weatherAuthorized = accuracy != 'NONE';
+
+        this._updateAutoLocation();
     }
 });
 Signals.addSignalMethods(WeatherClient.prototype);
