@@ -12,7 +12,6 @@ const WebKit = imports.gi.WebKit2;
 const _ = Gettext.gettext;
 
 const Config = imports.misc.config;
-const FileUtils = imports.misc.fileUtils;
 
 const PortalHelperResult = {
     CANCELLED: 0,
@@ -141,12 +140,8 @@ const PortalWindow = new Lang.Class({
         this._doneCallback = doneCallback;
         this._lastRecheck = 0;
         this._recheckAtExit = false;
-        let cacheDir = GLib.Dir.make_tmp("gnome-shell-portal-helper-XXXXXXXX");
-        this._cacheDir = Gio.File.new_for_path(cacheDir);
 
-        let dataManager = new WebKit.WebsiteDataManager({ base_data_directory: cacheDir,
-                                                          base_cache_directory: cacheDir });
-        this._webContext = new WebKit.WebContext({ website_data_manager: dataManager });
+        this._webContext = WebKit.WebContext.new_ephemeral();
         this._webContext.set_cache_model(WebKit.CacheModel.DOCUMENT_VIEWER);
 
         this._webView = WebKit.WebView.new_with_context(this._webContext);
@@ -169,7 +164,6 @@ const PortalWindow = new Lang.Class({
 
     destroyWindow: function() {
         this.destroy();
-        FileUtils.recursivelyDeleteDir(this._cacheDir, true);
     },
 
     _syncUri: function() {
@@ -194,9 +188,9 @@ const PortalWindow = new Lang.Class({
     },
 
     _onLoadChanged: function(view, loadEvent) {
-        if (loadEvent == WebKit.LOAD_STARTED) {
+        if (loadEvent == WebKit.LoadEvent.STARTED) {
             this._headerBar.setSecurityIcon(PortalHelperSecurityLevel.NOT_YET_DETERMINED);
-        } else if (loadEvent == WebKit.LOAD_COMMITTED) {
+        } else if (loadEvent == WebKit.LoadEvent.COMMITTED) {
             let tlsInfo = this._webView.get_tls_info();
             let ret = tlsInfo[0];
             let flags = tlsInfo[2];
@@ -221,6 +215,18 @@ const PortalWindow = new Lang.Class({
 
     _onDecidePolicy: function(view, decision, type) {
         if (type == WebKit.PolicyDecisionType.NEW_WINDOW_ACTION) {
+            let navigationAction = decision.get_navigation_action();
+            if (navigationAction.is_user_gesture()) {
+                // Even though the portal asks for a new window,
+                // perform the navigation in the current one. Some
+                // portals open a window as their last login step and
+                // ignoring that window causes them to not let the
+                // user go through. We don't risk popups taking over
+                // the page because we check that the navigation is
+                // user initiated.
+                this._webView.load_request(navigationAction.get_request());
+            }
+
             decision.ignore();
             return true;
         }
@@ -363,6 +369,11 @@ function initEnvironment() {
 function main(argv) {
     initEnvironment();
 
+    if (!WebKit.WebContext.new_ephemeral) {
+        log('WebKitGTK 2.16 is required for the portal-helper, see https://bugzilla.gnome.org/show_bug.cgi?id=780453');
+        return 1;
+    }
+
     Gettext.bindtextdomain(Config.GETTEXT_PACKAGE, Config.LOCALEDIR);
     Gettext.textdomain(Config.GETTEXT_PACKAGE);
 
