@@ -21,8 +21,8 @@ const RENAMED_DESKTOP_IDS = {
     'gnibbles.desktop': 'org.gnome.Nibbles.desktop',
     'gnobots2.desktop': 'gnome-robots.desktop',
     'gnome-boxes.desktop': 'org.gnome.Boxes.desktop',
-    'gnome-clocks.desktop': 'org.gnome.clocks.desktop',
     'gnome-calculator.desktop': 'org.gnome.Calculator.desktop',
+    'gnome-clocks.desktop': 'org.gnome.clocks.desktop',
     'gnome-contacts.desktop': 'org.gnome.Contacts.desktop',
     'gnome-documents.desktop': 'org.gnome.Documents.desktop',
     'gnome-font-viewer.desktop': 'org.gnome.font-viewer.desktop',
@@ -59,12 +59,14 @@ const AppFavorites = new Lang.Class({
 
     reload: function() {
         let ids = global.settings.get_strv(this.FAVORITE_APPS_KEY);
+        let appSys = Shell.AppSystem.get_default();
 
         // Map old desktop file names to the current ones
         let updated = false;
         ids = ids.map(function (id) {
             let newId = RENAMED_DESKTOP_IDS[id];
-            if (newId !== undefined) {
+            if (newId !== undefined &&
+                appSys.lookup_app(newId) != null) {
                 updated = true;
                 return newId;
             }
@@ -74,7 +76,6 @@ const AppFavorites = new Lang.Class({
         if (updated)
             global.settings.set_strv(this.FAVORITE_APPS_KEY, ids);
 
-        let appSys = Shell.AppSystem.get_default();
         let apps = ids.map(function (id) {
                 return appSys.lookup_app(id);
             }).filter(function (app) {
