@@ -64,7 +64,8 @@ function startAppForMount(app, mount) {
 
     try {
         retval = app.launch(files, 
-                            global.create_app_launch_context(0, -1))
+                            global.create_app_launch_context(0, -1),
+                            false)
     } catch (e) {
         log('Unable to launch the application ' + app.get_name()
             + ': ' + e.toString());
